<?php

namespace Drupal\search_api_elasticsearchkit_proxy\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\search_api\Entity\Server;

/**
 * Configure Search API Elasticsearch server selection for the module.
 */
class ElasticsearchServerSelectionForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'search_api_elasticsearch_server_selection';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['search_api_elasticsearchkit_proxy.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('search_api_elasticsearchkit_proxy.settings');

    // Get all available Search API servers.
    $servers = Server::loadMultiple();
    $options = [];
    foreach ($servers as $id => $server) {
      $options[$id] = $server->label();
    }

    $form['search_api_server'] = [
      '#type' => 'select',
      '#title' => $this->t('Select Search API Server'),
      '#description' => $this->t('Select the Search API server that you want to use for Elasticsearch queries.'),
      '#options' => $options,
      '#default_value' => $config->get('search_api_server'),
      '#required' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('search_api_elasticsearchkit_proxy.settings')
      ->set('search_api_server', $form_state->getValue('search_api_server'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
